@@ -400,9 +400,10 @@ void GameArea::Layout()
   Object::Layout();
 }
 
-void GameArea::Draw(int x, int y, size_t w, size_t h)
+void GameArea::Draw(Lum::OS::DrawInfo* draw,
+                    int x, int y, size_t w, size_t h)
 {
-  Object::Draw(x,y,w,h);
+  Object::Draw(draw,x,y,w,h);
 
   if (!OIntersect(x,y,w,h)) {
     return;
@@ -410,8 +411,7 @@ void GameArea::Draw(int x, int y, size_t w, size_t h)
 
   /* --- */
 
-  Lum::OS::DrawInfo *draw=GetDrawInfo();
-  size_t            offset;
+  size_t offset;
 
   //
   // Draw game area
@@ -552,9 +552,22 @@ void GameArea::Draw(int x, int y, size_t w, size_t h)
   draw->PopFont();
 }
 
-bool GameArea::HandlesFocus() const
+bool GameArea::HandlesClickFocus() const
 {
-  return Object::HandlesFocus() && !finished->Get();
+  return CanFocus() &&
+         IsVisible() &&
+         finished.Valid() &&
+         !finished->IsNull() &&
+         !finished->Get();
+}
+
+bool GameArea::HandlesKeyFocus() const
+{
+  return CanFocus() &&
+         IsVisible() &&
+         finished.Valid() &&
+         !finished->IsNull() &&
+         !finished->Get();
 }
 
 bool GameArea::HandleMouseEvent(const Lum::OS::MouseEvent& event)
