@@ -21,7 +21,6 @@
 #include <vector>
 
 #include <Lum/Base/L10N.h>
-#include <Lum/Base/Path.h>
 #include <Lum/Base/String.h>
 
 #include <Lum/Def/Menu.h>
@@ -34,6 +33,7 @@
 #include <Lum/Images/Image.h>
 #include <Lum/Images/Loader.h>
 
+#include <Lum/Application.h>
 #include <Lum/Array.h>
 #include <Lum/AspectRatio.h>
 #include <Lum/Button.h>
@@ -49,7 +49,7 @@
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
 
-#include <Lum/OS/Main.h>
+#include <Lum/Manager/FileSystem.h>
 
 #include "config.h"
 #include "Configuration.h"
@@ -629,15 +629,11 @@ public:
   }
 };
 
-class Main : public Lum::OS::MainDialog<MainDialog>
+class Main : public Lum::GUIApplication<MainDialog>
 {
 public:
-  bool Prepare()
+  bool Initialize()
   {
-#if defined(APP_DATADIR)
-    Lum::Base::Path::SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
-#endif
-
     info.SetProgram(Lum::Base::StringToWString(PACKAGE_NAME));
     info.SetVersion(Lum::Base::StringToWString(PACKAGE_VERSION));
     info.SetDescription(_(L"ABOUT_DESC",L"A simple Sudoku implementation..."));
@@ -646,28 +642,38 @@ public:
     info.SetCopyright(L"(c) 2006, Tim Teulings");
     info.SetLicense(L"GNU Public License");
 
+#if defined(APP_DATADIR)
+    Lum::Manager::FileSystem::Instance()->SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
+#endif
+
+    std::wstring appDataDir;
+
+    if (Lum::Manager::FileSystem::Instance()->GetEntry(Lum::Manager::FileSystem::appDataDir,
+                                                       appDataDir)) {
+
+      Lum::Base::Path path;
+
+      path.SetNativeDir(appDataDir);
+      path.AppendDir(L"icons");
+
+      Lum::Images::loader->AddApplicationSearchPath(path);
+    }
+
     Lum::Base::Path path;
 
-    path.SetNativeDir(Lum::Base::Path::GetApplicationDataDir());
-    path.AppendDir(L"icons");
-
-    Lum::Images::loader->AddApplicationSearchPath(path);
-
-    path.SetRoot(L"");
     path.SetDir(L"data");
     path.AppendDir(L"icons");
     path.AppendDir(L"16x16");
     Lum::Images::loader->AddApplicationSearchPath(path);
 
-
-    return Lum::OS::MainDialog<MainDialog>::Prepare();
+    return Lum::GUIApplication<MainDialog>::Initialize();
   }
 
   void Cleanup()
   {
     FreeConfig();
 
-    Lum::OS::MainDialog<MainDialog>::Cleanup();
+    Lum::GUIApplication<MainDialog>::Cleanup();
   }
 };
 
